@@ -139,31 +139,19 @@ DelAtt BossAct1(ObjData *my)
 DelAtt BossHit1(ObjData *my, ObjData *your)
 {
   int temp = your->Attack;
-#ifdef DEBUG
-  fprintf(stderr, "BossHit1: %d damage attack ", temp);
-#endif
   
   if ((my->Cnt[0] < my->Cnt[1]) || (manage->BossTime <=0))
     {
-#ifdef DEBUG
-  fprintf(stderr, "(not counted)\n");
-#endif
       return NoneDel;
     }
     
     if (my->HP < temp)
     {
-#ifdef DEBUG
-      fprintf(stderr, "(overkill, %d is enough) ", my->HP);
-#endif
       temp = my->HP;
     }
     
     my->HP -= temp;
     player->Rec[0].score += temp;
-#ifdef DEBUG
-      fprintf(stderr, "%d remaining\n", my->HP);
-#endif
     
     if (my->HP <= 0)
     {
