@@ -6,6 +6,9 @@
  */
 /* $Id: enemyshot.c,v 1.7 2002/04/29 16:54:59 oohara Exp $ */
 
+#include <stdio.h>
+#include <stdlib.h>
+
 /*
 #include <X11/Xlib.h>
 #include <X11/xpm.h>
