@@ -4,10 +4,12 @@
  *
  * This is a copyleft program.  See the file LICENSE for details.
  */
-/* $Id: joystick.c,v 1.5 2002/04/29 03:41:56 oohara Exp $ */
+/* $Id: joystick.c,v 1.6 2011/08/10 14:25:38 oohara Exp $ */
 
 #include <config.h>
 
+#ifdef JSTK
+
 /* read */
 #include <unistd.h>
 /* exit */
@@ -26,12 +28,20 @@
 #include "key.h"
 #include "extern.h"
 
+#endif /* JSTK */
+
 #include "joystick.h"
 
+#ifdef JSTK
+
 static int fd;
 
+#endif /* JSTK */
+
 void initJS(void)
 {
+#ifdef JSTK
+
     long tmpl;
 
     if ((fd=open("/dev/js0",O_RDONLY)) == -1)
@@ -50,10 +60,14 @@ void initJS(void)
         perror ("js_set");
         exit (1);
     }
+
+#endif /* JSTK */
 }
 
 void readJS(void)
 {
+#ifdef JSTK
+
     static struct JS_DATA_TYPE js;
     static int scrsv = 0;
     /* if the button 2 was pressed? */ 
@@ -94,4 +108,6 @@ void readJS(void)
 	if (js.y <  100) joymask |= Up;
 	if (js.y >  150) joymask |= Down; /* Was 1000 */
     }
+
+#endif /* JSTK */
 }
