@@ -4,7 +4,7 @@
  *
  * This is a copyleft program.  See the file LICENSE for details.
  */
-/* $Id: joystick.h,v 1.2 2002/04/12 00:18:52 oohara Exp $ */
+/* $Id: joystick.h,v 1.3 2011/08/10 14:25:42 oohara Exp $ */
 
 #if !defined _JOYSTICK_H_
 #define _JOYSTICK_H_
@@ -12,4 +12,4 @@
 extern void initJS(void);
 extern void readJS(void);
 
-#endif
+#endif /* not _JOYSTICK_H_ */
