@@ -4,7 +4,7 @@
  *
  * This is a copyleft program.  See the file LICENSE for details.
  */
-/* $Id: main.c,v 1.30 2002/05/05 11:10:33 oohara Exp $ */
+/* $Id: main.c,v 1.31 2006/09/16 09:20:54 oohara Exp $ */
 
 /* DEBUG and JSTK are defined in config.h */
 #include <config.h>
@@ -105,7 +105,7 @@ int main(int argc, char *argv[])
     XFlush(dpy);
 #endif /* not HAVE_LIBSDL */
 
-    while (1)
+    while (!(manage->program_should_quit))
     {
 	keymask = 0;
 
