@@ -4,7 +4,7 @@
  *
  * This is a copyleft program.  See the file LICENSE for details.
  */
-/* $Id: player.c,v 1.11 2002/04/29 17:00:15 oohara Exp $ */
+/* $Id: player.c,v 1.12 2011/08/12 14:33:57 oohara Exp $ */
 
 /* DEBUG is defined in config.h */
 #include <config.h>
@@ -294,9 +294,6 @@ DelAtt PlayerAction(ObjData *my)
       {
         /* releasing the shoot button gives you a score */
         player->Rec[0].score += (manage->EnemyNum) * 3;
-#ifdef DEBUG
-        fprintf(stderr, "PlayerAction: \"not shooting\" bonus %d (%d enemies in play)\n", (manage->EnemyNum) * 3, (manage->EnemyNum));
-#endif
       }
       else
         (my->notShootingTime)--;
