@@ -4,7 +4,7 @@
  *
  * This is a copyleft program.  See the file LICENSE for details.
  */
-/* $Id: score.c,v 1.10 2002/05/01 22:36:41 oohara Exp $ */
+/* $Id: score.c,v 1.11 2011/08/12 14:29:02 oohara Exp $ */
 
 /* DEBUG and DUPSCORE are defined in config.h */
 #include <config.h>
@@ -32,9 +32,7 @@
 
 static void fake_score_entry(Record *rec, int n, int score);
 static void copy_Record_to_PlayerData(Record *rec, PlayerData *p);
-
-/* this is not public --- only for qsort */
-int compare_entry(const void *a, const void *b);
+static int compare_entry(const void *a, const void *b);
 
 
 /* read entries from high score file and save them in p
@@ -270,7 +268,7 @@ static void copy_Record_to_PlayerData(Record *rec, PlayerData *p)
     p->Rec[i] = rec[i - 1];
 }
 
-int compare_entry(const void *a, const void *b)
+static int compare_entry(const void *a, const void *b)
 {
   const Record *rec_a = (const Record *) a;
   const Record *rec_b = (const Record *) b;
