@@ -4,7 +4,7 @@
  *
  * This is a copyleft program.  See the file LICENSE for details.
  */
-/* $Id: version.h,v 1.7 2009/11/08 06:18:27 oohara Exp $ */
+/* $Id: version.h,v 1.10 2011/08/12 15:17:14 oohara Exp $ */
 
 #include <config.h>
 #if !defined _VERSION_H_
@@ -12,6 +12,6 @@
 
 /* VERSION is defined in config.h because we use automake */
 
-#define UPDATE "08 Nov 2009"
+#define UPDATE "13 Aug 2011"
 
 #endif
